@@ -321,12 +321,3 @@ class Graph:
             if round(abs(i), pz) == 0.0:
                 c = c + 1
         return c
-
-
-if __name__ == "__main__":
-    import os
-    import doctest
-
-    os.chdir(os.path.dirname(__file__))
-    doctest.testmod()
-    print("Doctest of molgemtools.graph...")
